@@ -74,6 +74,38 @@ def test_get_topic_total_records():
 
     http_status_code, error_message, query_result = metrics_client.get_topic_total(KafkaMetric.RECEIVED_RECORDS, kafka_cluster_id, kafka_topic_name, query_start_time, query_end_time)
  
+    try:
+        logger.info("HTTP Status Code: %d, Error Message: %s, Query Result: %s", http_status_code, error_message, query_result)
+        assert http_status_code == HttpStatus.OK, f"HTTP Status Code: {http_status_code}"
+    except AssertionError as e:
+        logger.error(e)
+        logger.error("HTTP Status Code: %d, Error Message: %s, Query Result: %s", http_status_code, error_message, query_result)
+
+
+def test_get_topic_daily_aggregated_totals_bytes():
+    """Test the get_topic_daily_aggregated_totals() function for getting the daily aggregated totals bytes."""
+
+    # Instantiate the MetricsClient class.
+    metrics_client = MetricsClient(metrics_config)
+
+    http_status_code, error_message, query_result = metrics_client.get_topic_daily_aggregated_totals(KafkaMetric.RECEIVED_BYTES, kafka_cluster_id, kafka_topic_name)
+ 
+    try:
+        logger.info("HTTP Status Code: %d, Error Message: %s, Query Result: %s", http_status_code, error_message, query_result)
+        assert http_status_code == HttpStatus.OK, f"HTTP Status Code: {http_status_code}"
+    except AssertionError as e:
+        logger.error(e)
+        logger.error("HTTP Status Code: %d, Error Message: %s, Query Result: %s", http_status_code, error_message, query_result)
+    
+
+def test_get_topic_daily_aggregated_totals_records():
+    """Test the get_topic_daily_aggregated_totals() function for getting the daily aggregated totals records."""
+
+    # Instantiate the MetricsClient class.
+    metrics_client = MetricsClient(metrics_config)
+
+    http_status_code, error_message, query_result = metrics_client.get_topic_daily_aggregated_totals(KafkaMetric.RECEIVED_RECORDS, kafka_cluster_id, kafka_topic_name)
+ 
     try:
         logger.info("HTTP Status Code: %d, Error Message: %s, Query Result: %s", http_status_code, error_message, query_result)
         assert http_status_code == HttpStatus.OK, f"HTTP Status Code: {http_status_code}"
